==> cantata_2.1.0.ds1.orig.tar.gz: cantata-2.1.0/README.md <==
Introduction
============

Cantata is a graphical client for MPD, supporting the following features:

 1. Support for Linux, MacOSX, and Windows.
 2. Multiple MPD collections.
 3. Highly customisable layout.
 4. Songs grouped by album in play queue.
 5. Context view to show artist, album, and song information of current track.
 6. Simple tag editor.
 7. File organizer - use tags to organize files and folders.
 8. Ability to calculate ReplyGain tags. (Linux only, and if relevant libraries
    installed)
 9. Dynamic playlists.
 10. Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
 11. Radio stream support - with the ability to search for streams via TuneIn,
    ShoutCast, or Dirble.
 12. USB-Mass-Storage and MTP device support. (Linux only, and if relevant
    libraries installed)
 13. Audio CD ripping and playback. (Linux only, and if relevant libraries
    installed)
 14. Playback of non-MPD songs - via simple in-built HTTP server if connected
    to MPD via a standard socket, otherwise filepath is sent to MPD.
 15. MPRISv2 DBUS interface.
 16. Basic support for touch-style interface (views are made 'flickable')
 17. Scrobbling.
 18. Ratings support.

Cantata started off as a fork of QtMPC, however, the code (and user interface)
is now *very* different to that of QtMPC.
For more detailed information, please refer to the main [README](https://raw.githubusercontent.com/CDrummond/cantata/master/README)

Screenshots

===========

Some (outdated, 1.x) screenshots can be found at the [kde-apps](http://kde-apps.org/content/show.php/Cantata?content=147733) page.

Downloads
=========

Curently I'm developing v2.0, and as such the older 1.x is no longer actively
maintained (the code base is *very* different). However, these older versions
may still be downloaded from [Cantata's github wiki](https://github.com/CDrummond/cantata/wiki/Previous-%28Google-Code%29-Downloads)

==> cantata_2.2.0.ds1.orig.tar.gz: cantata-2.2.0/README.md <==
Introduction
============

Cantata is a graphical client for MPD, supporting the following features:

 1. Support for Linux, MacOSX, and Windows.
 2. Multiple MPD collections.
 3. Highly customisable layout.
 4. Songs grouped by album in play queue.
 5. Context view to show artist, album, and song information of current track.
 6. Simple tag editor.
 7. File organizer - use tags to organize files and folders.
 8. Ability to calculate ReplyGain tags. (Linux only, and if relevant libraries
    installed)
 9. Dynamic playlists.
 10. Online services; Jamendo, Magnatune, SoundCloud, and Podcasts.
 11. Radio stream support - with the ability to search for streams via TuneIn,
    ShoutCast, or Dirble.
 12. USB-Mass-Storage and MTP device support. (Linux only, and if relevant
    libraries installed)
 13. Audio CD ripping and playback. (Linux only, and if relevant libraries
    installed)
 14. Playback of non-MPD songs - via simple in-built HTTP server if connected
    to MPD via a standard socket, otherwise filepath is sent to MPD.
 15. MPRISv2 DBUS interface.
 16. Basic support for touch-style interface (views are made 'flickable')
 17. Scrobbling.
 18. Ratings support.

Cantata started off as a fork of QtMPC, however, the code (and user interface)
is now *very* different to that of QtMPC.
For more detailed information, please refer to the main [README](https://raw.githubusercontent.com/CDrummond/cantata/master/README)

Screenshots
===========

Some (outdated, 1.x) screenshots can be found at the [kde-apps](http://kde-apps.org/content/show.php/Cantata?content=147733) page.

Downloads
=========

Curently I'm developing v2, and as such the older 1.x is no longer actively
maintained (the code base is *very* different). However, these older versions
may still be downloaded from [Cantata's github wiki](https://github.com/CDrummond/cantata/wiki/Previous-%28Google-Code%29-Downloads)


---

[![Say Thanks!](https://img.shields.io/badge/Say%20Thanks-!-1EAEDB.svg)](https://saythanks.io/to/craigd)
